pub struct AdvancedVoiceOptions {
pub low_latency_journey_synthesis: Option<bool>,
pub relax_safety_filters: Option<bool>,
}Expand description
Used for advanced voice options.
This type is not used in any activity, and only used as part of another schema.
Fields
low_latency_journey_synthesis: Option<bool>Only for Journey voices. If false, the synthesis is context aware and has a higher latency.
relax_safety_filters: Option<bool>Optional. Input only. If true, relaxes safety filters for Gemini TTS. Only supported for accounts linked to Invoiced (Offline) Cloud billing accounts. Otherwise, will return result google.rpc.Code.INVALID_ARGUMENT.