pub struct CustomPronunciationParams {
pub phonetic_encoding: Option<String>,
pub phrase: Option<String>,
pub pronunciation: Option<String>,
}Expand description
Pronunciation customization for a phrase.
This type is not used in any activity, and only used as part of another schema.
Fields
phonetic_encoding: Option<String>The phonetic encoding of the phrase.
phrase: Option<String>The phrase to which the customization is applied. The phrase can be multiple words, such as proper nouns, but shouldn’t span the length of the sentence.
pronunciation: Option<String>The pronunciation of the phrase. This must be in the phonetic encoding specified above.