pub struct ListVoicesResponse {
pub voices: Option<Vec<Voice>>,
}Expand description
The message returned to the client by the ListVoices method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list voices (response)
Fields
voices: Option<Vec<Voice>>The list of voices.