pub struct MultiSpeakerVoiceConfig {
pub speaker_voice_configs: Option<Vec<MultispeakerPrebuiltVoice>>,
}Expand description
Configuration for a multi-speaker text-to-speech setup. Enables the use of up to two distinct voices in a single synthesis request.
This type is not used in any activity, and only used as part of another schema.
Fields
speaker_voice_configs: Option<Vec<MultispeakerPrebuiltVoice>>Required. A list of configurations for the voices of the speakers. Exactly two speaker voice configurations must be provided.