pub struct MultispeakerPrebuiltVoice {
pub speaker_alias: Option<String>,
pub speaker_id: Option<String>,
}Expand description
Configuration for a single speaker in a Gemini TTS multi-speaker setup. Enables dialogue between two speakers.
This type is not used in any activity, and only used as part of another schema.
Fields
speaker_alias: Option<String>Required. The speaker alias of the voice. This is the user-chosen speaker name that is used in the multispeaker text input, such as “Speaker1”.
speaker_id: Option<String>Required. The speaker ID of the voice. See https://cloud.google.com/text-to-speech/docs/gemini-tts#voice_options for available values.